[FFmpeg-cvslog] rename new lls code to lls2 to avoid conflict with the old which has a different ABI

Michael Niedermayer git at videolan.org
Tue Dec 24 04:00:58 CET 2013


ffmpeg | branch: release/2.0 | Michael Niedermayer <michaelni at gmx.at> | Sat Nov 16 16:42:57 2013 +0100| [0cd61c7f7d105ec6b1652be2a1fce029fade16db] | committer: Michael Niedermayer

rename new lls code to lls2 to avoid conflict with the old which has a different ABI

also remove failed attempt at a compatibility layer, the code simply cannot work

Signed-off-by: Michael Niedermayer <michaelni at gmx.at>
(cherry picked from commit c3814ab654a993723b0e5f14cc252d68f233ad79)

Conflicts:

	libavcodec/version.h

> http://git.videolan.org/gitweb.cgi/ffmpeg.git/?a=commit;h=0cd61c7f7d105ec6b1652be2a1fce029fade16db
---

 libavcodec/lpc.c         |    6 +++---
 libavutil/lls2.c         |   35 ++++++++---------------------------
 libavutil/lls2.h         |   23 ++++++++---------------
 libavutil/x86/lls.asm    |    8 ++++----
 libavutil/x86/lls_init.c |    8 ++++----
 5 files changed, 27 insertions(+), 53 deletions(-)

diff --git a/libavcodec/lpc.c b/libavcodec/lpc.c
index 1989030..a6f2377 100644
--- a/libavcodec/lpc.c
+++ b/libavcodec/lpc.c
@@ -208,7 +208,7 @@ int ff_lpc_calc_coefs(LPCContext *s,
     }
 
     if (lpc_type == FF_LPC_TYPE_CHOLESKY) {
-        LLSModel m[2];
+        LLSModel2 m[2];
         LOCAL_ALIGNED(32, double, var, [FFALIGN(MAX_LPC_ORDER+1,4)]);
         double av_uninit(weight);
         memset(var, 0, FFALIGN(MAX_LPC_ORDER+1,4)*sizeof(*var));
@@ -217,7 +217,7 @@ int ff_lpc_calc_coefs(LPCContext *s,
             m[0].coeff[max_order-1][j] = -lpc[max_order-1][j];
 
         for(; pass<lpc_passes; pass++){
-            avpriv_init_lls(&m[pass&1], max_order);
+            avpriv_init_lls2(&m[pass&1], max_order);
 
             weight=0;
             for(i=max_order; i<blocksize; i++){
@@ -238,7 +238,7 @@ int ff_lpc_calc_coefs(LPCContext *s,
 
                 m[pass&1].update_lls(&m[pass&1], var);
             }
-            avpriv_solve_lls(&m[pass&1], 0.001, 0);
+            avpriv_solve_lls2(&m[pass&1], 0.001, 0);
         }
 
         for(i=0; i<max_order; i++){
diff --git a/libavutil/lls2.c b/libavutil/lls2.c
index f381ebc..8cadacb 100644
--- a/libavutil/lls2.c
+++ b/libavutil/lls2.c
@@ -32,7 +32,7 @@
 #include "version.h"
 #include "lls2.h"
 
-static void update_lls(LLSModel *m, double *var)
+static void update_lls(LLSModel2 *m, double *var)
 {
     int i, j;
 
@@ -43,7 +43,7 @@ static void update_lls(LLSModel *m, double *var)
     }
 }
 
-void avpriv_solve_lls(LLSModel *m, double threshold, unsigned short min_order)
+void avpriv_solve_lls2(LLSModel2 *m, double threshold, unsigned short min_order)
 {
     int i, j, k;
     double (*factor)[MAX_VARS_ALIGN] = (void *) &m->covariance[1][0];
@@ -100,7 +100,7 @@ void avpriv_solve_lls(LLSModel *m, double threshold, unsigned short min_order)
     }
 }
 
-static double evaluate_lls(LLSModel *m, double *param, int order)
+static double evaluate_lls(LLSModel2 *m, double *param, int order)
 {
     int i;
     double out = 0;
@@ -111,9 +111,9 @@ static double evaluate_lls(LLSModel *m, double *param, int order)
     return out;
 }
 
-av_cold void avpriv_init_lls(LLSModel *m, int indep_count)
+av_cold void avpriv_init_lls2(LLSModel2 *m, int indep_count)
 {
-    memset(m, 0, sizeof(LLSModel));
+    memset(m, 0, sizeof(LLSModel2));
     m->indep_count = indep_count;
     m->update_lls = update_lls;
     m->evaluate_lls = evaluate_lls;
@@ -121,25 +121,6 @@ av_cold void avpriv_init_lls(LLSModel *m, int indep_count)
         ff_init_lls_x86(m);
 }
 
-#if FF_API_LLS_PRIVATE
-av_cold void av_init_lls(LLSModel *m, int indep_count)
-{
-    avpriv_init_lls(m, indep_count);
-}
-void av_update_lls(LLSModel *m, double *param, double decay)
-{
-    m->update_lls(m, param);
-}
-void av_solve_lls(LLSModel *m, double threshold, int min_order)
-{
-    avpriv_solve_lls(m, threshold, min_order);
-}
-double av_evaluate_lls(LLSModel *m, double *param, int order)
-{
-    return m->evaluate_lls(m, param, order);
-}
-#endif /* FF_API_LLS_PRIVATE */
-
 #ifdef TEST
 
 #include <stdio.h>
@@ -148,12 +129,12 @@ double av_evaluate_lls(LLSModel *m, double *param, int order)
 
 int main(void)
 {
-    LLSModel m;
+    LLSModel2 m;
     int i, order;
     AVLFG lfg;
 
     av_lfg_init(&lfg, 1);
-    avpriv_init_lls(&m, 3);
+    avpriv_init_lls2(&m, 3);
 
     for (i = 0; i < 100; i++) {
         LOCAL_ALIGNED(32, double, var, [4]);
@@ -164,7 +145,7 @@ int main(void)
         var[2] = var[1] + av_lfg_get(&lfg) / (double) UINT_MAX - 0.5;
         var[3] = var[2] + av_lfg_get(&lfg) / (double) UINT_MAX - 0.5;
         m.update_lls(&m, var);
-        avpriv_solve_lls(&m, 0.001, 0);
+        avpriv_solve_lls2(&m, 0.001, 0);
         for (order = 0; order < 3; order++) {
             eval = m.evaluate_lls(&m, var + 1, order);
             printf("real:%9f order:%d pred:%9f var:%f coeffs:%f %9f %9f\n",
diff --git a/libavutil/x86/lls.asm b/libavutil/x86/lls.asm
index 769befb..c2aead3 100644
--- a/libavutil/x86/lls.asm
+++ b/libavutil/x86/lls.asm
@@ -29,7 +29,7 @@ SECTION .text
 %define COVAR_STRIDE MAX_VARS_ALIGN*8
 %define COVAR(x,y) [covarq + (x)*8 + (y)*COVAR_STRIDE]
 
-struc LLSModel
+struc LLSModel2
     .covariance:  resq MAX_VARS_ALIGN*MAX_VARS_ALIGN
     .coeff:       resq MAX_VARS*MAX_VARS
     .variance:    resq MAX_VARS
@@ -49,7 +49,7 @@ INIT_XMM sse2
 %define movdqa movaps
 cglobal update_lls, 2,5,8, ctx, var, i, j, covar2
     %define covarq ctxq
-    mov     id, [ctxq + LLSModel.indep_count]
+    mov     id, [ctxq + LLSModel2.indep_count]
     lea   varq, [varq + iq*8]
     neg     iq
     mov covar2q, covarq
@@ -129,7 +129,7 @@ cglobal update_lls, 2,5,8, ctx, var, i, j, covar2
 INIT_YMM avx
 cglobal update_lls, 3,6,8, ctx, var, count, i, j, count2
     %define covarq ctxq
-    mov  countd, [ctxq + LLSModel.indep_count]
+    mov  countd, [ctxq + LLSModel2.indep_count]
     lea count2d, [countq-2]
     xor     id, id
 .loopi:
@@ -206,7 +206,7 @@ cglobal evaluate_lls, 3,4,2, ctx, var, order, i
     %define coefsq ctxq
     mov     id, orderd
     imul    orderd, MAX_VARS
-    lea     coefsq, [ctxq + LLSModel.coeff + orderq*8]
+    lea     coefsq, [ctxq + LLSModel2.coeff + orderq*8]
     movsd   m0, [varq]
     movhpd  m0, [varq + 8]
     mulpd   m0, [coefsq]
diff --git a/libavutil/x86/lls_init.c b/libavutil/x86/lls_init.c
index b2424b3..bf999d5 100644
--- a/libavutil/x86/lls_init.c
+++ b/libavutil/x86/lls_init.c
@@ -23,11 +23,11 @@
 #include "libavutil/lls2.h"
 #include "libavutil/x86/cpu.h"
 
-void ff_update_lls_sse2(LLSModel *m, double *var);
-void ff_update_lls_avx(LLSModel *m, double *var);
-double ff_evaluate_lls_sse2(LLSModel *m, double *var, int order);
+void ff_update_lls_sse2(LLSModel2 *m, double *var);
+void ff_update_lls_avx(LLSModel2 *m, double *var);
+double ff_evaluate_lls_sse2(LLSModel2 *m, double *var, int order);
 
-av_cold void ff_init_lls_x86(LLSModel *m)
+av_cold void ff_init_lls_x86(LLSModel2 *m)
 {
     int cpu_flags = av_get_cpu_flags();
     if (EXTERNAL_SSE2(cpu_flags)) {



More information about the ffmpeg-cvslog mailing list
diff --git a/libavutil/lls2.h b/libavutil/lls2.h
index c62d78a..35815d2 100644
--- a/libavutil/lls2.h
+++ b/libavutil/lls2.h
@@ -30,12 +30,12 @@
 #define MAX_VARS 32
 #define MAX_VARS_ALIGN FFALIGN(MAX_VARS+1,4)
 
 //FIXME avoid direct access to LLSModel from outside
 
 /**
  * Linear least squares model.
  */
-typedef struct LLSModel {
+typedef struct LLSModel2 {
     DECLARE_ALIGNED(32, double, covariance[MAX_VARS_ALIGN][MAX_VARS_ALIGN]);
     DECLARE_ALIGNED(32, double, coeff[MAX_VARS][MAX_VARS]);
     double variance[MAX_VARS];
@@ -47,25 +47,18 @@ typedef struct LLSModel {
      *            32-byte aligned, and any padding elements must be initialized
      *            (i.e not denormal/nan).
      */
-    void (*update_lls)(struct LLSModel *m, double *var);
+    void (*update_lls)(struct LLSModel2 *m, double *var);
     /**
      * Inner product of var[] and the LPC coefs.
      * @param m this context
      * @param var training samples, excluding the value to be predicted. unaligned.
      * @param order lpc order
      */
-    double (*evaluate_lls)(struct LLSModel *m, double *var, int order);
-} LLSModel;
+    double (*evaluate_lls)(struct LLSModel2 *m, double *var, int order);
+} LLSModel2;
 
-void avpriv_init_lls(LLSModel *m, int indep_count);
-void ff_init_lls_x86(LLSModel *m);
-void avpriv_solve_lls(LLSModel *m, double threshold, unsigned short min_order);
-
-#if FF_API_LLS_PRIVATE
-void av_init_lls(LLSModel *m, int indep_count);
-void av_update_lls(LLSModel *m, double *param, double decay);
-void av_solve_lls(LLSModel *m, double threshold, int min_order);
-double av_evaluate_lls(LLSModel *m, double *param, int order);
-#endif /* FF_API_LLS_PRIVATE */
+void avpriv_init_lls2(LLSModel2 *m, int indep_count);
+void ff_init_lls_x86(LLSModel2 *m);
+void avpriv_solve_lls2(LLSModel2 *m, double threshold, unsigned short min_order);
 
 #endif /* AVUTIL_LLS_H */
@@ -30,12 +30,12 @@
 #define MAX_VARS_ALIGN FFALIGN(MAX_VARS+1,4)
 
-//FIXME avoid direct access to LLSModel from outside
+//FIXME avoid direct access to LLSModel2 from outside
 
 /**